@@ -1,7 +1,7 @@
 search.arima <- function(x, d=NA, D=NA, max.p=5, max.q=5,
     max.P=2, max.Q=2, max.order=5, stationary=FALSE, ic=c("aic","aicc","bic"),
     trace=FALSE,approximation=FALSE,xreg=NULL,offset=offset,allowdrift=TRUE,
-    parallel=FALSE, num.cores=NULL)
+    parallel=FALSE, num.cores=2)
 {
     #dataname <- substitute(x)
     ic <- match.arg(ic)
